==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateSectionHeaderCellInfoDescriptionMetadata, _super);
    function TemplateSectionHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.g(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.c = function (a) {
        SectionHeaderCellInfoDescriptionMetadata.c(a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
        a.u("TemplateSectionHeaderCellInfo", function () { return new TemplateSectionHeaderCellInfoDescription(); });
        a.t("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderCellInfoDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TemplateSectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionHeaderCellInfoDescriptionMetadata } from "./SectionHeaderCellInfoDescriptionMetadata";
import { TemplateSectionHeaderCellInfoDescription } from "./TemplateSectionHeaderCellInfoDescription";
/**
 * @hidden
 */
var TemplateSectionHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateSectionHeaderCellInfoDescriptionMetadata, _super);
    function TemplateSectionHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateSectionHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (TemplateSectionHeaderCellInfoDescriptionMetadata.a == null) {
            TemplateSectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateSectionHeaderCellInfoDescriptionMetadata.c(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.j(TemplateSectionHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateSectionHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.c = function (a) {
        SectionHeaderCellInfoDescriptionMetadata.c(a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.d = function (a) {
        TemplateSectionHeaderCellInfoDescriptionMetadata.b(a);
        a.aa("TemplateSectionHeaderCellInfo", function () { return new TemplateSectionHeaderCellInfoDescription(); });
        a.z("TemplateSectionHeaderCellInfo", TemplateSectionHeaderCellInfoDescriptionMetadata.a);
    };
    TemplateSectionHeaderCellInfoDescriptionMetadata.$t = markType(TemplateSectionHeaderCellInfoDescriptionMetadata, 'TemplateSectionHeaderCellInfoDescriptionMetadata');
    TemplateSectionHeaderCellInfoDescriptionMetadata.a = null;
    return TemplateSectionHeaderCellInfoDescriptionMetadata;
}(Base));
export { TemplateSectionHeaderCellInfoDescriptionMetadata };
